' VBScript - Update Sage.jar Build Number for Windows
' by Hiltronix 2016-01-09
'
' This file should reside in the root of the SageTV repo to function correctly.
' Functionality is dependent on the GitHub desktop app being installed, 
' and the path to the ...\Git\bin\ folder being added to the System Path variable.
'
' *** NOTICE: This script updates a text file on your copmputer.  Use at your own risk. ***

Option Explicit

Dim sCommand, build, rtn

' Get current working directory.
Dim SageTVRepoPath, fso
Set fso = CreateObject("Scripting.FileSystemObject")
SageTVRepoPath = fso.GetAbsolutePathName(".")
Set fso = Nothing

sCommand = CHR(34) & "git.exe" & CHR(34) & " -C " & CHR(34) & SageTVRepoPath & CHR(34) & " rev-list HEAD --count"

build = runCMD(sCommand)

If build = "" Then
	build = 0
End If

If build = 0 Then
	rtn = PopUpMsg("Git Execution Error", "GIT.EXE had an error, is not installed, or is not set in the System Path variable.", vbInformation)
	wscript.quit
End If

If PopUpMsg("SageTV Build Number", "GitHub build number is currently " & build & vbCRLF  & vbCRLF & "Update SageConstants.java file?", vbQuestion + vbOKCancel) = 1 Then
	rtn = UpdateFile(build)
	If rtn = False Then
		rtn = PopUpMsg("File Update Error", "There was an error updating the SageConstants.java file.", vbCritical)
		wscript.quit
	End If
	rtn = PopUpMsg("SageConstants.java File", "Update Successful!", vbInformation)
End If


Function PopUpMsg(title, msgText, buttons)
' Popup text box that will disappear after 3 seconds.

	Dim WshShell, rtn

	Set WshShell = CreateObject( "WScript.Shell" )

	rtn = WshShell.Popup(msgText, 0 , title, buttons)
	' For values see: http://www.devguru.com/technologies/wsh/17415 

	Set WshShell = Nothing
	
	PopUpMsg = rtn
	
End Function


Function RunCMD(strRunCmd)

	Dim objShell, objExec, strOut

	Set objShell = WScript.CreateObject("WScript.Shell")

	On Error Resume Next
	Set objExec = objShell.Exec(strRunCmd)
	If Err.Number <> 0 Then
	    RunCMD = 0
	    Exit Function
	End If
	
	strOut = ""
	
	Do While Not objExec.StdOut.AtEndOfStream
		strOut = strOut & objExec.StdOut.ReadLine()
	Loop
	
	Set objShell = Nothing
	Set objExec = Nothing
	
	RunCMD = strOut

End Function


Function UpdateFile(build)

	Dim fso, objRegEx
	Dim strFile, strPattern, strReplaceString, strSearchString, strNewString
	
	strFile = SageTVRepoPath & "\java\sage\SageConstants.java"
	
	Set fso = CreateObject("Scripting.FileSystemObject")
	
	strPattern = "BUILD_VERSION(.*?)\;"
	
	strReplaceString = "BUILD_VERSION = " & build & ";"
	
	On Error Resume Next
	strSearchString = fso.OpenTextFile(strFile, 1).ReadAll
	If Err.Number <> 0 Then
	    UpdateFile = False
	    Exit Function
	End If
	
	Set objRegEx = CreateObject("VBScript.RegExp")
	
	objRegEx.Global = True   
	objRegEx.IgnoreCase = True
	objRegEx.Pattern = strPattern
	
	strNewString = objRegEx.Replace(strSearchString, strReplaceString)
	                     
	On Error Resume Next
	fso.OpenTextFile(strFile, 2, True).WriteLine strNewString
	If Err.Number <> 0 Then
	    UpdateFile = False
	    Exit Function
	End If

	UpdateFile = True

End Function


